from typing import Union

from azure.core.credentials import TokenCredential


class BlobStorageConfig:
    """Configuration settings for BlobStorage."""

    def __init__(
        self,
        container_name: str,
        connection_string: str = "",
        url: str = "",
        credential: Union[TokenCredential, None] = None,
    ):
        """Configuration settings for BlobStorage.

        container_name: The name of the blob container.
        connection_string: The connection string to the storage account.
        url: The URL of the blob service. If provided, credential must also be provided.
        credential: The TokenCredential to use for authentication when using a custom URL.

        credential-based authentication is prioritized over connection string authentication.
        """
        self.container_name: str = container_name
        self.connection_string: str = connection_string
        self.url: str = url
        self.credential: Union[TokenCredential, None] = credential



# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License.

"""
Error resources for Microsoft Agents Storage Blob package.
"""

from microsoft_agents.hosting.core.errors import ErrorMessage

from .error_resources import BlobStorageErrorResources

# Singleton instance
blob_storage_errors = BlobStorageErrorResources()

__all__ = ["ErrorMessage", "BlobStorageErrorResources", "blob_storage_errors"]



# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License.

"""
Blob storage error resources for Microsoft Agents SDK.

Error codes are in the range -61100 to -61199.
"""

from microsoft_agents.hosting.core.errors import ErrorMessage


class BlobStorageErrorResources:
    """
    Error messages for blob storage operations.

    Error codes are organized in the range -61100 to -61199.
    """

    BlobStorageConfigRequired = ErrorMessage(
        "BlobStorage: BlobStorageConfig is required.",
        -61100,
    )

    BlobConnectionStringOrUrlRequired = ErrorMessage(
        "BlobStorage: either connection_string or container_url is required.",
        -61101,
    )

    BlobContainerNameRequired = ErrorMessage(
        "BlobStorage: container_name is required.",
        -61102,
    )

    InvalidConfiguration = ErrorMessage(
        "Invalid configuration: {0}",
        -61103,
    )

    def __init__(self):
        """Initialize BlobStorageErrorResources."""
        pass
